<?php
/*
	Plugin Name: Fast Translate
	Plugin URI: http://wordpress.org/plugins/fast-translate
	Description: Faster WordPress localization with cache support.
	Version: 1.2.1
	Author: Björn Ahrens, Aucor Oy
	Author URI: 
	License: GPL3
*/

if( !class_exists( 'Fast_Translate_Dynamic_MO_Loader' ) ) {
	require_once( 'class.wppp_mo_dynamic.php' );

	class Fast_Translate_Dynamic_MO_Loader {

		function __construct() {
			add_filter( 'override_load_textdomain', array( $this, 'load_textdomain_override' ), 0, 3 );
		}

		function is_object_cache_installed() {
			global $wp_object_cache;
			return ( file_exists ( WP_CONTENT_DIR . '/object-cache.php' )
					&& get_class( $wp_object_cache ) != 'WP_Object_Cache' );
		}

		function load_textdomain_override( $retval, $domain, $mofile ) {
			global $l10n;

			$result = false;
			$mo = NULL;

			if ( $mo === NULL ) {
				do_action( 'load_textdomain', $domain, $mofile );
				$mofile = apply_filters( 'load_textdomain_mofile', $mofile, $domain );

				if ( isset( $l10n[$domain] ) ) {
					if ( $l10n[$domain] instanceof WPPP_MO_dynamic && $l10n[$domain]->Mo_file_loaded( $mofile ) ) {
						return true;
					}
				}

				if ( !is_readable( $mofile ) ) {
					return false; // return false is important so load_plugin_textdomain/load_theme_textdomain/... can call load_textdomain for different locations
				}

				$mo = new WPPP_MO_dynamic ( $domain, $this->is_object_cache_installed(), 'wppp1.0' );

				if ( $mo->import_from_file( $mofile ) ) { 
					$result = true;
				} else {
					$mo->unhook_and_close();
					$mo = NULL;
				}
			}

			if ( $mo !== NULL ) {
				if ( isset( $l10n[$domain] ) ) {
					$mo->merge_with( $l10n[$domain] );
					if ( $l10n[$domain] instanceof WPPP_MO_dynamic ) {
						$l10n[$domain]->unhook_and_close();
					}
				}
				$l10n[$domain] = $mo;
			}

			return $result;
		}
	}
}

if ( class_exists( 'Fast_Translate_Dynamic_MO_Loader' ) ) {
	// instantiate the plugin class
	$Fast_Translate_Dynamic_MO_Loader = new Fast_Translate_Dynamic_MO_Loader();
}